@@ -7,7 +7,7 @@ import re
 ##### Verilerin okunması #####
 ##############################
 def dataRead(path_):
-    veri_df = pd.read_csv(path_,header=None)
+    veri_df = pd.read_csv(path_)
     return veri_df
 
 #####################################
